// +build never

// TODO(you): uncomment build tag when decls_test.go is filled

package histogram

import "github.com/joeshaw/gengen/generic"

// TODO(you): fill in this function as described below.
func testValues() []generic.T {
	panic("fill this function to provide one or more distinct values")
}

// TODO(you): replace this with a function that returns some
// histogram to use in tests.
func testHistogram() *Histogram {
	panic("fill in with appropriate code")
}

var benchValueSets = []struct {
	name string
	data []generic.T
}{
	// TODO(you)[optional]: fill those in with some value sets to use
	// in benchmark.
}
